function restful(path) {
    function success(fn) {
        return function (ans) {
            if (typeof ans !== 'object' || !('status' in ans)) {
                return fn(50000);
            }
            if (ans.status != 0) {
                return fn(ans.status, ans.data);
            }
            fn(null, ans.data);
        };
    }
    function fail(fn) {
        return function () {
            fn(50000);
        };
    }
    return {
        get: function (data, fn) {
            if (!fn) {
                fn = data;
                data = {};
            }

            if (typeof data == 'object') {
                return $.get(path, data, success(fn), 'json').fail(fail(fn));
            }
            return $.get(path + '/' + data, success(fn), 'json').fail(fail(fn));
        },
        post: function (data, fn) {
            $.post(path, JSON.stringify(data), success(fn), 'json').fail(fail(fn));
        },
        put: function (id, data, fn) {
            $.ajax(path + '/' + id, {
                method: 'PUT',
                data: JSON.stringify(data),
                dataType: 'json',
                success: success(fn),
                error: fail(fn)
            });
        },
        delete: function (id, fn) {
            $.ajax(path + '/' + id, {
                method: 'DELETE',
                dataType: 'json',
                success: success(fn),
                error: fail(fn)
            });
        }
    };
}
